<?php

namespace Drupal\extra_field_example\Plugin\ExtraField\Display;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\extra_field\Plugin\ExtraFieldDisplayFormattedBase;

/**
 * Example Extra field Display.
 *
 * @ExtraFieldDisplay(
 *   id = "multilingual_field",
 *   label = @Translation("Concatenated tags"),
 *   bundles = {
 *     "node.article"
 *   }
 * )
 */
class ExampleMultilingualField extends ExtraFieldDisplayFormattedBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(ContentEntityInterface $entity) {

    $elements = [];
    if ($tagsField = $this->getTagsField()) {

      // Build the field output as a concatenation of tags.
      $tags = [];
      foreach ($tagsField as $item) {
        $tags[] = $item->entity->label();
      }
      $elements = ['#markup' => implode(', ', $tags)];
    }

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function getLabel() {

    $label = '';
    if ($tagsField = $this->getTagsField()) {
      // Use the Tags field's label.
      $label = $tagsField->getFieldDefinition()->getLabel();
    }

    return $label;
  }

  /**
   * {@inheritdoc}
   */
  public function getLabelDisplay() {
    // Override the default label display setting.
    return 'inline';
 }

  /**
   * {@inheritdoc}
   */
  public function isTranslatable() {
    // Override the default translatability setting.
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
 public function getLangcode() {

   if ($tagsField = $this->getTagsField()) {
     $langcode = $tagsField->getLangcode();
   }
   else {
     $langcode = parent::getLangcode();
   }

   return $langcode;
 }

  /**
   * Returns the Tags field this plugin uses.
   *
   * @return \Drupal\Core\Field\FieldItemListInterface|null
   */
  protected function getTagsField() {
    $field = NULL;
    $entity = $this->getEntity();

    if ($entity->hasField('field_tags')) {
      $field = $entity->get('field_tags');
    }
    return $field;
 }

}
